@@ -13,23 +13,21 @@ import sys
 from gi.repository import Gdk
 from gi.repository import Gtk
 from gi.repository import GLib
-from gi.repository import GObject
 
-from pychess.compat import urlopen, urlparse, basestring, open, pathname2url, url2pathname, unquote
-from pychess.System import conf, uistuff, prefix, SubProcess, Log, idle_add
-from pychess.System.uistuff import POSITION_NONE, POSITION_CENTER, POSITION_GOLDEN
+from pychess.compat import urlopen, basestring, open, pathname2url, url2pathname, unquote
+from pychess.System import conf, uistuff, prefix, SubProcess, idle_add
+from pychess.System.uistuff import POSITION_GOLDEN
 from pychess.System.Log import log, LogPipe
 from pychess.System.LogEmitter import GLogHandler, logemitter
-from pychess.System.debug import start_thread_dump, dump_threads
+from pychess.System.debug import start_thread_dump
 from pychess.System.prefix import getUserDataPrefix, addUserDataPrefix
-from pychess.Utils.const import HINT, NAME, SPY
+from pychess.Utils.const import HINT, NAME, SPY, MENU_ITEMS
+from pychess.Utils.checkversion import checkversion
 from pychess.widgets import enginesDialog
 from pychess.widgets import newGameDialog
 from pychess.widgets import tipOfTheDay
 from pychess.widgets.discovererDialog import DiscovererDialog
-from pychess.widgets.BorderBox import BorderBox
 from pychess.widgets import gamewidget
-from pychess.widgets import gamenanny
 from pychess.widgets import ionest
 from pychess.widgets import analyzegameDialog
 from pychess.widgets import preferencesDialog, gameinfoDialog, playerinfoDialog
@@ -39,37 +37,38 @@ from pychess.widgets.TaskerManager import InternetGameTasker
 from pychess.Players.engineNest import discoverer
 from pychess.Savers import chesspastebin
 from pychess.ic import ICLogon
-#from pychess.Database.gamelist import GameList
+# from pychess.Database.gamelist import GameList
 from pychess import VERSION, VERSION_NAME
 
-leftkeys  = map(Gdk.keyval_from_name, ("Left", "KP_Left"))
+leftkeys = map(Gdk.keyval_from_name, ("Left", "KP_Left"))
 rightkeys = map(Gdk.keyval_from_name, ("Right", "KP_Right"))
-upkeys    = map(Gdk.keyval_from_name, ("Up", "KP_Up"))
-downkeys  = map(Gdk.keyval_from_name, ("Down", "KP_Down"))
-homekeys  = map(Gdk.keyval_from_name, ("Home", "KP_Home"))
-endkeys   = map(Gdk.keyval_from_name, ("End", "KP_End"))
-functionkeys = [Gdk.keyval_from_name(k) for k in ("F1", "F2", "F3", "F4", "F5",
-                "F6", "F7", "F8", "F9", "F10", "F11")]
+upkeys = map(Gdk.keyval_from_name, ("Up", "KP_Up"))
+downkeys = map(Gdk.keyval_from_name, ("Down", "KP_Down"))
+homekeys = map(Gdk.keyval_from_name, ("Home", "KP_Home"))
+endkeys = map(Gdk.keyval_from_name, ("End", "KP_End"))
+functionkeys = [Gdk.keyval_from_name(k)
+                for k in ("F1", "F2", "F3", "F4", "F5", "F6", "F7", "F8", "F9",
+                          "F10", "F11")]
 
-################################################################################
-# gameDic - containing the gamewidget:gamemodel of all open games              #
-################################################################################
+# gameDic - containing the gamewidget:gamemodel of all open games
 gameDic = {}
 
-########################
-#  For Racent Chooser 
-########################
 recentManager = Gtk.RecentManager.get_default()
 
+TARGET_TYPE_URI_LIST = 0xbadbeef
+DRAG_ACTION = Gdk.DragAction.COPY
+DRAG_RESTRICT = Gtk.TargetFlags.OTHER_APP
+DND_LIST = [Gtk.TargetEntry.new("text/uri-list", DRAG_RESTRICT, TARGET_TYPE_URI_LIST)]
+
 
 class GladeHandlers:
-    
-    def on_window_key_press (window, event):
+    def on_window_key_press(window, event):
         log.debug('on_window_key_press: %s %s' % (window.get_title(), event))
         # Tabbing related shortcuts
         if not gamewidget.getheadbook():
             pagecount = 0
-        else: pagecount = gamewidget.getheadbook().get_n_pages()
+        else:
+            pagecount = gamewidget.getheadbook().get_n_pages()
         if pagecount > 1:
             if event.get_state() & Gdk.ModifierType.CONTROL_MASK:
                 page_num = gamewidget.getheadbook().get_current_page()
@@ -77,18 +76,22 @@ class GladeHandlers:
                 if event.get_state() & Gdk.ModifierType.SHIFT_MASK:
                     child = gamewidget.getheadbook().get_nth_page(page_num)
                     if event.keyval == Gdk.KEY_Page_Up:
-                        gamewidget.getheadbook().reorder_child(child, (page_num-1)%pagecount)
+                        gamewidget.getheadbook().reorder_child(child, (
+                            page_num - 1) % pagecount)
                         return True
                     elif event.keyval == Gdk.KEY_Page_Down:
-                        gamewidget.getheadbook().reorder_child(child, (page_num+1)%pagecount)
+                        gamewidget.getheadbook().reorder_child(child, (
+                            page_num + 1) % pagecount)
                         return True
                 # Change selected
                 else:
                     if event.keyval == Gdk.KEY_Page_Up:
-                        gamewidget.getheadbook().set_current_page((page_num-1)%pagecount)
+                        gamewidget.getheadbook().set_current_page(
+                            (page_num - 1) % pagecount)
                         return True
                     elif event.keyval == Gdk.KEY_Page_Down:
-                        gamewidget.getheadbook().set_current_page((page_num+1)%pagecount)
+                        gamewidget.getheadbook().set_current_page(
+                            (page_num + 1) % pagecount)
                         return True
 
         gmwidg = gamewidget.cur_gmwidg()
@@ -96,7 +99,7 @@ class GladeHandlers:
             for panel in gmwidg.panels:
                 focused = panel.get_focus_child()
                 # Do nothing in chat panel
-                if focused is not None and isinstance(focused, BorderBox):
+                if focused is not None and isinstance(focused, Gtk.Entry):
                     return False
 
             # Navigate on boardview with arrow keys
@@ -135,77 +138,87 @@ class GladeHandlers:
                 return True
 
             return False
-    
-    def on_gmwidg_created (handler, gmwidg, gamemodel):
+
+    def on_gmwidg_created(self, gmwidg, gamemodel):
         log.debug("GladeHandlers.on_gmwidg_created: starting")
         gameDic[gmwidg] = gamemodel
-        
+
         # Bring playing window to the front
         gamewidget.getWidgets()["window1"].present()
 
-        gamemodel.connect("game_loaded", GladeHandlers.__dict__["on_recent_game_activated"])
-        gamemodel.connect("game_saved", GladeHandlers.__dict__["on_recent_game_activated"])
-        
+        gamemodel.connect("game_loaded",
+                          GladeHandlers.__dict__["on_recent_game_activated"])
+        gamemodel.connect("game_saved",
+                          GladeHandlers.__dict__["on_recent_game_activated"])
+
         # Make sure we can remove gamewidgets from gameDic later
         gmwidg.connect("closed", GladeHandlers.__dict__["on_gmwidg_closed"])
         log.debug("GladeHandlers.on_gmwidg_created: returning")
 
-    def on_recent_game_activated (gamemodel, uri):
+    def on_recent_game_activated(gamemodel, uri):
         if isinstance(uri, basestring):
             path = url2pathname(uri)
-            if GObject.pygobject_version >= (3, 7, 4):
-                recent_data = Gtk.RecentData()
-                recent_data.mime_type = 'application/x-chess-pgn'
-                recent_data.app_name = 'pychess'
-                recent_data.app_exec = 'pychess'
-                #recent_data.groups = ['pychess']    # cannot add groups in python https://bugzilla.gnome.org/show_bug.cgi?id=695970
-                recentManager.add_full("file:"+pathname2url(path), recent_data)
-            else:
-                recentManager.add_item("file:"+pathname2url(path))
-    
-    def on_gmwidg_closed (gmwidg):
+            recentManager.add_item("file:" + pathname2url(path))
+
+    def on_gmwidg_closed(gmwidg):
         log.debug("GladeHandlers.on_gmwidg_closed")
         del gameDic[gmwidg]
         if not gameDic:
-            for widget in gamewidget.MENU_ITEMS:
-                gamewidget.getWidgets()[widget].set_property('sensitive', False)
-    
+            for widget in MENU_ITEMS:
+                gamewidget.getWidgets()[widget].set_property('sensitive',
+                                                             False)
+
     #          Drag 'n' Drop          #
-    
-    def on_drag_received (self, wi, context, x, y, selection, target_type, timestamp):
-        uri = selection.data.strip()
-        uris = uri.split()
-        if len(uris) > 1:
-            log.warning("%d files were dropped. Only loading the first" % len(uris))
-        uri = uris[0]
-        newGameDialog.LoadFileExtension.run(uri)
-    
-    #          Game Menu          #
-    
+
+    def on_drag_received(self, widget, context, x, y, selection, target_type,
+                         timestamp):
+        if target_type == TARGET_TYPE_URI_LIST:
+            uris = selection.get_uris()
+            if len(uris) == 1 and uris[0].lower().endswith(".pgn"):
+                uri = uris[0]
+                newGameDialog.LoadFileExtension.run(uri)
+            else:
+                newGameDialog.loadFilesAndRun(uris)
+
+    # Game Menu
+
     def on_new_game1_activate(self, widget):
         newGameDialog.NewGameMode.run()
-    
+
     def on_play_internet_chess_activate(self, widget):
         ICLogon.run()
-    
+
     def on_load_game1_activate(self, widget):
         newGameDialog.LoadFileExtension.run(None)
-    
+
     def on_set_up_position_activate(self, widget):
-        newGameDialog.SetupPositionExtension.run()
+        gmwidg = gamewidget.cur_gmwidg()
+        if gmwidg is not None:
+            if len(gmwidg.gamemodel.boards) == 1:
+                ply = 0
+            else:
+                ply = gmwidg.board.view.shown
+            fen = gmwidg.gamemodel.boards[ply].asFen()
+        else:
+            fen = None
+        newGameDialog.SetupPositionExtension.run(fen)
 
     def on_open_database_activate(self, widget):
-        #GameList().load_games()
+        # GameList().load_games()
         pass
-    
+
     def on_enter_game_notation_activate(self, widget):
         newGameDialog.EnterNotationExtension.run()
-    
+
     def on_save_game1_activate(self, widget):
-        ionest.saveGame (gameDic[gamewidget.cur_gmwidg()])
-    
+        gmwidg = gamewidget.cur_gmwidg()
+        position = gmwidg.board.view.shown
+        ionest.saveGame(gameDic[gamewidget.cur_gmwidg()], position)
+
     def on_save_game_as1_activate(self, widget):
-        ionest.saveGameAs (gameDic[gamewidget.cur_gmwidg()])
+        gmwidg = gamewidget.cur_gmwidg()
+        position = gmwidg.board.view.shown
+        ionest.saveGameAs(gameDic[gamewidget.cur_gmwidg()], position)
 
     def on_share_game_activate(self, widget):
         chesspastebin.paste(gameDic[gamewidget.cur_gmwidg()])
@@ -213,37 +226,38 @@ class GladeHandlers:
     def on_export_position_activate(self, widget):
         gmwidg = gamewidget.cur_gmwidg()
         position = gmwidg.board.view.shown
-        ionest.saveGameAs (gameDic[gmwidg], position)
+        ionest.saveGameAs(gameDic[gmwidg], position, export=True)
 
     def on_analyze_game_activate(self, widget):
         analyzegameDialog.run(gameDic)
 
     def on_properties1_activate(self, widget):
         gameinfoDialog.run(gamewidget.getWidgets(), gameDic)
-    
+
     def on_player_rating1_activate(self, widget):
         playerinfoDialog.run(gamewidget.getWidgets())
-    
+
     def on_close1_activate(self, widget):
         gmwidg = gamewidget.cur_gmwidg()
-        response = ionest.closeGame(gmwidg, gameDic[gmwidg])
-    
+        ionest.closeGame(gmwidg, gameDic[gmwidg])
+
     def on_quit1_activate(self, widget, *args):
         if isinstance(widget, Gdk.Event):
             if len(gameDic) == 1 and conf.get("hideTabs", False):
                 gmwidg = gamewidget.cur_gmwidg()
-                response = ionest.closeGame(gmwidg, gameDic[gmwidg])
+                ionest.closeGame(gmwidg, gameDic[gmwidg])
                 return True
             elif len(gameDic) >= 1 and conf.get("closeAll", False):
-                response = ionest.closeAllGames(gameDic.items())
+                ionest.closeAllGames(gameDic.items())
                 return True
-        if ionest.closeAllGames(gameDic.items()) in (Gtk.ResponseType.OK, Gtk.ResponseType.YES):
+        if ionest.closeAllGames(gameDic.items()) in (Gtk.ResponseType.OK,
+                                                     Gtk.ResponseType.YES):
             Gtk.main_quit()
         else:
             return True
 
-    #          View Menu          #
-    
+    # View Menu
+
     def on_rotate_board1_activate(self, widget):
         gmwidg = gamewidget.cur_gmwidg()
         if gmwidg.board.view.rotation:
@@ -251,29 +265,32 @@ class GladeHandlers:
         else:
             gmwidg.board.view.rotation = math.pi
 
-    
     def on_fullscreen1_activate(self, widget):
         gamewidget.getWidgets()["window1"].fullscreen()
         gamewidget.getWidgets()["fullscreen1"].hide()
         gamewidget.getWidgets()["leave_fullscreen1"].show()
-    
+
     def on_leave_fullscreen1_activate(self, widget):
         gamewidget.getWidgets()["window1"].unfullscreen()
         gamewidget.getWidgets()["leave_fullscreen1"].hide()
         gamewidget.getWidgets()["fullscreen1"].show()
-    
+
     def on_about1_activate(self, widget):
-        gamewidget.getWidgets()["aboutdialog1"].show()
-    
+        about_dialog = gamewidget.getWidgets()["aboutdialog1"]
+        response = about_dialog.run()
+        if response == Gtk.ResponseType.DELETE_EVENT or response == Gtk.ResponseType.CANCEL:
+            gamewidget.getWidgets()["aboutdialog1"].hide()
+
     def on_log_viewer1_activate(self, widget):
         from pychess.widgets import LogDialog
         if widget.get_active():
             LogDialog.show()
-        else: LogDialog.hide()
-    
+        else:
+            LogDialog.hide()
+
     def on_show_sidepanels_activate(self, widget):
         gamewidget.zoomToBoard(not widget.get_active())
-    
+
     def on_hint_mode_activate(self, widget):
         for gmwidg in gameDic.keys():
             if gmwidg.isInFront():
@@ -281,7 +298,7 @@ class GladeHandlers:
                     gmwidg.gamemodel.resume_analyzer(HINT)
                 else:
                     gmwidg.gamemodel.pause_analyzer(HINT)
-    
+
     def on_spy_mode_activate(self, widget):
         for gmwidg in gameDic.keys():
             if gmwidg.isInFront():
@@ -290,128 +307,106 @@ class GladeHandlers:
                 else:
                     gmwidg.gamemodel.pause_analyzer(SPY)
 
-    #          Edit menu          #
+    # Edit menu
 
     def on_copy_pgn_activate(self, widget):
         gamewidget.cur_gmwidg().copy_pgn()
 
     def on_copy_fen_activate(self, widget):
         gamewidget.cur_gmwidg().copy_fen()
-    
+
     def on_manage_engines_activate(self, widget):
         enginesDialog.run(gamewidget.getWidgets())
-    
+
     def on_preferences_activate(self, widget):
         preferencesDialog.run(gamewidget.getWidgets())
-    
-    #          Help menu          #
-    
+
+    # Help menu
+
     def on_about_chess1_activate(self, widget):
         webbrowser.open(_("http://en.wikipedia.org/wiki/Chess"))
-    
+
     def on_how_to_play1_activate(self, widget):
         webbrowser.open(_("http://en.wikipedia.org/wiki/Rules_of_chess"))
 
     def translate_this_application_activate(self, widget):
         webbrowser.open("https://www.transifex.com/projects/p/pychess/")
-        
+
     def on_TipOfTheDayMenuItem_activate(self, widget):
         tipOfTheDay.TipOfTheDay.show()
-    
-    #          Other          #
-    
-    def on_notebook2_switch_page (self, widget, page, page_num):
-        gamewidget.getWidgets()["notebook3"].set_current_page(page_num)
-    
-
-
-dnd_list = [ ('application/x-chess-pgn', 0, 0xbadbeef),
-             ('application/da-chess-pgn', 0, 0xbadbeef),
-             ('text/plain', 0, 0xbadbeef) ]
 
 
 class PyChess:
     def __init__(self, log_viewer, chess_file):
         self.git_rev = ""
-        
+
         self.initGlade(log_viewer)
         self.handleArgs(chess_file)
-    
+        checkversion()
+
     def initGlade(self, log_viewer):
-        #=======================================================================
         # Init glade and the 'GladeHandlers'
-        #=======================================================================
-        #Gtk.about_dialog_set_url_hook(self.website)
-        widgets = uistuff.GladeWidgets("PyChess.glade")       
+        widgets = uistuff.GladeWidgets("PyChess.glade")
         widgets.getGlade().connect_signals(GladeHandlers())
 
         tasker = TaskerManager()
-        new_game_tasker, internet_game_tasker = NewGameTasker(), InternetGameTasker()
-        tasker.packTaskers (new_game_tasker, internet_game_tasker)
+        new_game_tasker, internet_game_tasker = NewGameTasker(
+        ), InternetGameTasker()
+        tasker.packTaskers(new_game_tasker, internet_game_tasker)
         widgets["Background"].add(tasker)
-        
-        #------------------------------------------------------ Redirect widgets
+
+        # Redirect widgets
         gamewidget.setWidgets(widgets)
-        
-        def on_sensitive_changed (widget, prop):
-            name = widget.get_property('name')
-            sensitive = widget.get_property('sensitive')
-            #print "'%s' changed to '%s'" % (name, sensitive)
-        widgets['pause1'].connect("notify::sensitive", on_sensitive_changed)
-        widgets['resume1'].connect("notify::sensitive", on_sensitive_changed)
-        #-------------------------- Main.py still needs a minimum of information
+
+        # Main.py still needs a minimum of information
         ionest.handler.connect("gmwidg_created",
                                GladeHandlers.__dict__["on_gmwidg_created"])
-        
-        #---------------------- The only menuitems that need special initing
+
+        # The only menuitems that need special initing
         for widget in ("hint_mode", "spy_mode"):
             widgets[widget].set_sensitive(False)
 
         uistuff.keep(widgets["hint_mode"], "hint_mode", first_value=True)
         uistuff.keep(widgets["spy_mode"], "spy_mode", first_value=True)
-        uistuff.keep(widgets["show_sidepanels"], "show_sidepanels", first_value=True)
-        uistuff.keep(widgets["auto_call_flag"], "autoCallFlag", first_value=True)
-        
-        #=======================================================================
+        uistuff.keep(widgets["show_sidepanels"],
+                     "show_sidepanels",
+                     first_value=True)
+        uistuff.keep(widgets["auto_call_flag"],
+                     "autoCallFlag",
+                     first_value=True)
+
         # Show main window and init d'n'd
-        #=======================================================================
         widgets["window1"].set_title('%s - PyChess' % _('Welcome'))
         widgets["window1"].connect("delete-event",
                                    GladeHandlers.__dict__["on_quit1_activate"])
-        widgets["window1"].connect("key-press-event",
-                                   GladeHandlers.__dict__["on_window_key_press"])
-        uistuff.keepWindowSize("main", widgets["window1"], None, POSITION_GOLDEN)
+        widgets["window1"].connect(
+            "key-press-event", GladeHandlers.__dict__["on_window_key_press"])
+        uistuff.keepWindowSize("main", widgets["window1"], None,
+                               POSITION_GOLDEN)
         widgets["window1"].show()
         widgets["Background"].show_all()
-                
-        flags = Gtk.DestDefaults.MOTION | Gtk.DestDefaults.HIGHLIGHT | Gtk.DestDefaults.DROP
+
         # To get drag in the whole window, we add it to the menu and the
         # background. If it can be gotten to work, the drag_dest_set_proxy
         # method is very interesting.
-        #widgets["menubar1"].drag_dest_set(flags, dnd_list, Gdk.DragAction.COPY)
-        #widgets["Background"].drag_dest_set(flags, dnd_list, Gdk.DragAction.COPY)
-        # TODO: http://code.google.com/p/pychess/issues/detail?id=737
-        # The following two should really be set in the glade file
-        #widgets["menubar1"].set_events(widgets["menubar1"].get_events() | Gdk.DRAG_STATUS)
-        #widgets["Background"].set_events(widgets["Background"].get_events() | Gdk.DRAG_STATUS)
-        
-        #=======================================================================
+        widgets["menubar1"].drag_dest_set(Gtk.DestDefaults.ALL, DND_LIST, DRAG_ACTION)
+        widgets["Background"].drag_dest_set(Gtk.DestDefaults.ALL, DND_LIST, DRAG_ACTION)
+
         # Init 'minor' dialogs
-        #=======================================================================
-        
-        #------------------------------------------------------------ Log dialog
+
+        # Log dialog
         if log_viewer:
             from pychess.widgets import LogDialog
-            LogDialog.add_destroy_notify(lambda: widgets["log_viewer1"].set_active(0))
+            LogDialog.add_destroy_notify(
+                lambda: widgets["log_viewer1"].set_active(0))
         else:
             widgets["log_viewer1"].set_property('sensitive', False)
-            
-        #---------------------------------------------------------- About dialog
+
+        # About dialog
         self.aboutdialog = widgets["aboutdialog1"]
         self.aboutdialog.set_program_name(NAME)
-        link = self.aboutdialog.get_website()
-        self.aboutdialog.set_copyright("Copyright © 2006-2015")
-        self.aboutdialog.set_version(VERSION_NAME+" "+VERSION)
+        self.aboutdialog.set_copyright("Copyright © 2006-2016")
+        self.aboutdialog.set_version(VERSION_NAME + " " + VERSION)
         if os.path.isdir(prefix.addDataPrefix(".git")):
             try:
                 label = subprocess.check_output(["git", "describe"])
@@ -420,8 +415,9 @@ class PyChess:
             if label:
                 comments = self.aboutdialog.get_comments()
                 self.git_rev = label
-                self.aboutdialog.set_comments("git %s\n%s" % (self.git_rev, comments))
-        
+                self.aboutdialog.set_comments("git %s\n%s" %
+                                              (self.git_rev, comments))
+
         with open(prefix.addDataPrefix("ARTISTS"), encoding="utf-8") as f:
             self.aboutdialog.set_artists(f.read().splitlines())
         with open(prefix.addDataPrefix("AUTHORS"), encoding="utf-8") as f:
@@ -430,90 +426,94 @@ class PyChess:
             self.aboutdialog.set_documenters(f.read().splitlines())
         with open(prefix.addDataPrefix("TRANSLATORS"), encoding="utf-8") as f:
             self.aboutdialog.set_translator_credits(f.read())
+        with open(prefix.addDataPrefix("LICENSE"), encoding="utf-8") as f:
+            self.aboutdialog.set_license(f.read())
 
-        def on_about_response(dialog, response, *args):
-            # system-defined GtkDialog responses are always negative, in which    
-            # case we want to hide it
-            if response < 0:
-                self.aboutdialog.hide()
-                self.aboutdialog.emit_stop_by_name('response')
-
-        def on_about_close(widget, event=None):
-            self.aboutdialog.hide()
-            return True
-
-        self.aboutdialog.connect("response", on_about_response)
-        self.aboutdialog.connect("close", on_about_close)
-        self.aboutdialog.connect("delete-event", on_about_close)
-
-        #---------------------------------------------------- RecentChooser
-        def recent_item_activated (self):
+        # RecentChooser
+        def recent_item_activated(self):
             uri = self.get_current_uri()
             try:
                 urlopen(unquote(uri)).close()
                 newGameDialog.LoadFileExtension.run(self.get_current_uri())
             except (IOError, OSError):
-                #shomething wrong whit the uri
+                # shomething wrong whit the uri
                 recentManager.remove_item(uri)
-                
-        #self.menu_recent = Gtk.RecentChooserMenu(recentManager)
+
         self.menu_recent = Gtk.RecentChooserMenu()
         self.menu_recent.set_show_tips(True)
         self.menu_recent.set_sort_type(Gtk.RecentSortType.MRU)
         self.menu_recent.set_limit(10)
         self.menu_recent.set_name("menu_recent")
-        
+
         self.file_filter = Gtk.RecentFilter()
         self.file_filter.add_mime_type("application/x-chess-pgn")
         self.menu_recent.set_filter(self.file_filter)
 
         self.menu_recent.connect("item-activated", recent_item_activated)
         widgets["load_recent_game1"].set_submenu(self.menu_recent)
-        
-        #----------------------------------------------------- Discoverer dialog
-        def discovering_started (discoverer, binnames):
-            GLib.idle_add(DiscovererDialog.show, discoverer, widgets["window1"], binnames)
+
+        # Discoverer dialog
+        def discovering_started(discoverer, binnames):
+            GLib.idle_add(DiscovererDialog.show, discoverer,
+                          widgets["window1"], binnames)
+
         discoverer.connect("discovering_started", discovering_started)
         DiscovererDialog.init(discoverer)
         discoverer.discover()
-        
-        #------------------------------------------------- Tip of the day dialog
+
+        # Tip of the day dialog
         if conf.get("show_tip_at_startup", False):
             tipOfTheDay.TipOfTheDay.show()
 
         if conf.get("autoLogin", False):
             internet_game_tasker.connectClicked(None)
-            
+
     def website(self, clb, link):
         webbrowser.open(link)
-    
-    def handleArgs (self, chess_file):
+
+    def handleArgs(self, chess_file):
         if chess_file:
-            def do (discoverer):
+
+            def do(discoverer):
                 GLib.idle_add(newGameDialog.LoadFileExtension.run, chess_file)
+
             discoverer.connect_after("all_engines_discovered", do)
 
-def run (no_debug, idle_add_debug, thread_debug, log_viewer, chess_file,
-         ics_host, ics_port):
+
+def run(no_debug, idle_add_debug, thread_debug, log_viewer, purge_recent,
+        chess_file, ics_host, ics_port):
     # Start logging
     if log_viewer:
         log.logger.addHandler(GLogHandler(logemitter))
     log.logger.setLevel(logging.WARNING if no_debug is True else logging.DEBUG)
-    oldlogs = [l for l in os.listdir(getUserDataPrefix()) if l.endswith(".log")]
+    oldlogs = [l for l in os.listdir(getUserDataPrefix())
+               if l.endswith(".log")]
     conf.set("max_log_files", conf.get("max_log_files", 10))
-    if len(oldlogs) >= conf.get("max_log_files", 10):
-        oldlogs.sort()
+    oldlogs.sort()
+    l = len(oldlogs)
+    while l > conf.get("max_log_files", 10):
         try:
             os.remove(addUserDataPrefix(oldlogs[0]))
-        except OSError as e:
+            del oldlogs[0]
+        except OSError:
             pass
+        l -= 1
+
+    if purge_recent:
+        items = recentManager.get_items()
+        for item in items:
+            uri = item.get_uri()
+            if item.get_application_info("pychess"):
+                recentManager.remove_item(uri)
 
     signal.signal(signal.SIGINT, Gtk.main_quit)
     signal.signal(signal.SIGTERM, Gtk.main_quit)
-    def cleanup ():
+
+    def cleanup():
         SubProcess.finishAllSubprocesses()
+
     atexit.register(cleanup)
-    
+
     pychess = PyChess(log_viewer, chess_file)
     idle_add.debug = idle_add_debug
 
@@ -530,5 +530,5 @@ def run (no_debug, idle_add_debug, thread_debug, log_viewer, chess_file,
         ICLogon.host = ics_host
     if ics_port:
         ICLogon.port = ics_port
-    
+
     Gtk.main()
