@@ -1,36 +1,45 @@
+""" :Description: This module facilitates configurable object that the end user can
+    customise such as which chess setor board colours to use or the ability to turn on/off
+    various sidepanel facilities such as hints, comments engine analysis etc. It also allows
+    the user to setup and use customised sounds or no sounds at all for a variety of in game
+    events such as running out of time or piece movement events etc.
+"""
 from __future__ import print_function
 
 import os
-import sys
-import struct
 from os import listdir
 from os.path import isdir, isfile, splitext
+
+import sys
 from xml.dom import minidom
 
-from gi.repository import Gtk, GdkPixbuf
-from gi.repository import Gdk
+from gi.repository import Gtk, GdkPixbuf, Gdk
 
 from pychess.compat import pathname2url, url2pathname, unquote
 from pychess.System.prefix import addDataPrefix, getDataPrefix
 from pychess.System.idle_add import idle_add
 from pychess.System import conf, gstreamer, uistuff
 from pychess.Players.engineNest import discoverer
-from pychess.Utils.const import *
+from pychess.Utils.const import HINT, SPY, SOUND_MUTE, SOUND_BEEP, SOUND_URI, SOUND_SELECT
 from pychess.Utils.IconLoader import load_icon, get_pixbuf
 from pychess.gfx import Pieces
-from pychess.System.Log import log
-
+from .Background import hexcol
 
 firstRun = True
+
+
 def run(widgets):
     global firstRun
     if firstRun:
         initialize(widgets)
         firstRun = False
-    widgets["preferences"].show()
-    widgets["preferences"].present()
+    widgets["preferences_dialog"].show()
+    widgets["preferences_dialog"].present()
+
 
 def initialize(widgets):
+    """ :Description: Initialises the various tabs for each section of configurable artifacts
+    """
     GeneralTab(widgets)
     HintTab(widgets)
     SoundTab(widgets)
@@ -38,24 +47,22 @@ def initialize(widgets):
     ThemeTab(widgets)
     SaveTab(widgets)
 
+    uistuff.keepWindowSize("preferencesdialog", widgets["preferences_dialog"])
 
-    uistuff.keepWindowSize("preferencesdialog", widgets["preferences"])
-
-    def delete_event (widget, *args):
-        widgets["preferences"].hide()
+    def delete_event(widget, _):
+        widgets["preferences_dialog"].hide()
         return True
-    widgets["preferences"].connect("delete-event", delete_event)
-    widgets["preferences"].connect("key-press-event",
-        lambda w,e: w.event(Gdk.Event(Gdk.EventType.DELETE))
-        if e.keyval == Gdk.KEY_Escape else None)
 
-################################################################################
-# General initing                                                              #
-################################################################################
+    widgets["preferences_dialog"].connect("delete-event", delete_event)
+    widgets["preferences_dialog"].connect(
+        "key-press-event",
+        lambda w, e: w.event(Gdk.Event(Gdk.EventType.DELETE)) if e.keyval == Gdk.KEY_Escape else None)
+
+# General initing
+
 
 class GeneralTab:
-
-    def __init__ (self, widgets):
+    def __init__(self, widgets):
 
         conf.set("firstName", conf.get("firstName", conf.username))
         conf.set("secondName", conf.get("secondName", _("Guest")))
@@ -63,23 +70,25 @@ class GeneralTab:
         # Give to uistuff.keeper
 
         for key in ("firstName", "secondName", "showEmt", "showEval",
-                    "hideTabs", "closeAll", "faceToFace", "showCords", "showCaptured",
-                    "figuresInNotation", "fullAnimation", "moveAnimation", "noAnimation"):
+                    "autoPromote", "hideTabs", "closeAll", "faceToFace",
+                    "showCords", "showCaptured", "figuresInNotation",
+                    "fullAnimation", "moveAnimation", "noAnimation"):
             uistuff.keep(widgets[key], key)
 
         # Options on by default
         for key in ("autoRotate", "fullAnimation", "showBlunder"):
             uistuff.keep(widgets[key], key, first_value=True)
 
-################################################################################
-# Hint initing                                                               #
-################################################################################
+# Hint initing
 
-def anal_combo_get_value (combobox):
+
+def anal_combo_get_value(combobox):
     engine = list(discoverer.getAnalyzers())[combobox.get_active()]
     return engine.get("md5")
 
-def anal_combo_set_value (combobox, value, show_arrow_check, ana_check, analyzer_type):
+
+def anal_combo_set_value(combobox, value, show_arrow_check, ana_check,
+                         analyzer_type):
     engine = discoverer.getEngineByMd5(value)
     if engine is None:
         combobox.set_active(0)
@@ -106,8 +115,9 @@ def anal_combo_set_value (combobox, value, show_arrow_check, ana_check, analyzer
             if not widgets[show_arrow_check].get_active():
                 gmwidg.gamemodel.pause_analyzer(analyzer_type)
 
+
 class HintTab:
-    def __init__ (self, widgets):
+    def __init__(self, widgets):
         self.widgets = widgets
 
         # Options on by default
@@ -120,9 +130,12 @@ class HintTab:
         path = conf.get("opening_file_entry", default_path)
         conf.set("opening_file_entry", path)
 
-        book_chooser_dialog = Gtk.FileChooserDialog(_("Select book file"), None, Gtk.FileChooserAction.OPEN,
-            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
-        book_chooser_button = Gtk.FileChooserButton.new_with_dialog(book_chooser_dialog)
+        book_chooser_dialog = Gtk.FileChooserDialog(
+            _("Select book file"), None, Gtk.FileChooserAction.OPEN,
+            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN,
+             Gtk.ResponseType.OK))
+        book_chooser_button = Gtk.FileChooserButton.new_with_dialog(
+            book_chooser_dialog)
 
         filter = Gtk.FileFilter()
         filter.set_name(_("Opening books"))
@@ -143,19 +156,24 @@ class HintTab:
 
         book_chooser_button.connect("file-set", select_new_book)
 
-        def on_opening_check_toggled (check):
+        def on_opening_check_toggled(check):
             widgets["opening_hbox"].set_sensitive(check.get_active())
+
         widgets["opening_check"].connect_after("toggled",
-                                                on_opening_check_toggled)
+                                               on_opening_check_toggled)
 
         # Endgame
         default_path = os.path.join(getDataPrefix())
         egtb_path = conf.get("egtb_path", default_path)
         conf.set("egtb_path", egtb_path)
 
-        egtb_chooser_dialog = Gtk.FileChooserDialog(_("Select Gaviota TB path"), None, Gtk.FileChooserAction.SELECT_FOLDER,
-            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
-        egtb_chooser_button = Gtk.FileChooserButton.new_with_dialog(egtb_chooser_dialog)
+        egtb_chooser_dialog = Gtk.FileChooserDialog(
+            _("Select Gaviota TB path"), None,
+            Gtk.FileChooserAction.SELECT_FOLDER,
+            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN,
+             Gtk.ResponseType.OK))
+        egtb_chooser_button = Gtk.FileChooserButton.new_with_dialog(
+            egtb_chooser_dialog)
         egtb_chooser_button.set_current_folder(egtb_path)
 
         self.widgets["egtbChooserDock"].add(egtb_chooser_button)
@@ -168,25 +186,26 @@ class HintTab:
 
         egtb_chooser_button.connect("current-folder-changed", select_egtb)
 
-        def on_endgame_check_toggled (check):
+        def on_endgame_check_toggled(check):
             widgets["endgame_hbox"].set_sensitive(check.get_active())
 
         widgets["endgame_check"].connect_after("toggled",
-                                                on_endgame_check_toggled)
+                                               on_endgame_check_toggled)
 
         # Analyzing engines
         from pychess.widgets import newGameDialog
         data = [(item[0], item[1]) for item in newGameDialog.analyzerItems]
-        uistuff.createCombo(widgets["ana_combobox"], data)
-        uistuff.createCombo(widgets["inv_ana_combobox"], data)
+        uistuff.createCombo(widgets["ana_combobox"], data, name="ana_combobox")
+        uistuff.createCombo(widgets["inv_ana_combobox"], data, name="inv_ana_combobox")
 
         @idle_add
         def update_analyzers_store(discoverer):
             data = [(item[0], item[1]) for item in newGameDialog.analyzerItems]
             uistuff.updateCombo(widgets["ana_combobox"], data)
             uistuff.updateCombo(widgets["inv_ana_combobox"], data)
+
         discoverer.connect_after("all_engines_discovered",
-                            update_analyzers_store)
+                                 update_analyzers_store)
         update_analyzers_store(discoverer)
 
         # Save, load and make analyze combos active
@@ -196,7 +215,7 @@ class HintTab:
         conf.set("ana_combobox", conf.get("ana_combobox", default))
         conf.set("inv_ana_combobox", conf.get("inv_ana_combobox", default))
 
-        def on_analyzer_check_toggled (check):
+        def on_analyzer_check_toggled(check):
             widgets["analyzers_vbox"].set_sensitive(check.get_active())
             from pychess.Main import gameDic
             if gameDic:
@@ -209,12 +228,12 @@ class HintTab:
                     for gmwidg in gameDic.keys():
                         gmwidg.gamemodel.remove_analyzer(HINT)
 
-        widgets["analyzers_vbox"].set_sensitive(
-            widgets["analyzer_check"].get_active())
+        widgets["analyzers_vbox"].set_sensitive(widgets[
+            "analyzer_check"].get_active())
         widgets["analyzer_check"].connect_after("toggled",
                                                 on_analyzer_check_toggled)
 
-        def on_invanalyzer_check_toggled (check):
+        def on_invanalyzer_check_toggled(check):
             widgets["inv_analyzers_vbox"].set_sensitive(check.get_active())
             from pychess.Main import gameDic
             if gameDic:
@@ -227,25 +246,26 @@ class HintTab:
                     for gmwidg in gameDic.keys():
                         gmwidg.gamemodel.remove_analyzer(SPY)
 
-        widgets["inv_analyzers_vbox"].set_sensitive(
-            widgets["inv_analyzer_check"].get_active())
-        widgets["inv_analyzer_check"].connect_after("toggled",
-                                              on_invanalyzer_check_toggled)
+        widgets["inv_analyzers_vbox"].set_sensitive(widgets[
+            "inv_analyzer_check"].get_active())
+        widgets["inv_analyzer_check"].connect_after(
+            "toggled", on_invanalyzer_check_toggled)
 
         # Give widgets to keeper
 
-        uistuff.keep(widgets["ana_combobox"], "ana_combobox", anal_combo_get_value,
-            lambda combobox, value: anal_combo_set_value(combobox, value, "hint_mode",
-                                              "analyzer_check", HINT))
-        uistuff.keep(widgets["inv_ana_combobox"], "inv_ana_combobox", anal_combo_get_value,
-            lambda combobox, value: anal_combo_set_value(combobox, value, "spy_mode",
-                                              "inv_analyzer_check", SPY))
+        uistuff.keep(
+            widgets["ana_combobox"], "ana_combobox", anal_combo_get_value,
+            lambda combobox, value: anal_combo_set_value(combobox, value, "hint_mode", "analyzer_check", HINT))
+        uistuff.keep(
+            widgets["inv_ana_combobox"], "inv_ana_combobox",
+            anal_combo_get_value,
+            lambda combobox, value: anal_combo_set_value(combobox, value, "spy_mode", "inv_analyzer_check", SPY))
 
-        uistuff.keep(widgets["max_analysis_spin"], "max_analysis_spin", first_value=3)
+        uistuff.keep(widgets["max_analysis_spin"],
+                     "max_analysis_spin",
+                     first_value=3)
 
-################################################################################
-# Sound initing                                                                #
-################################################################################
+# Sound initing
 
 # Setup default sounds
 EXT = "wav" if sys.platform == "win32" else "ogg"
@@ -254,27 +274,39 @@ for i in range(11):
     if not conf.hasKey("soundcombo%d" % i):
         conf.set("soundcombo%d" % i, SOUND_URI)
 if not conf.hasKey("sounduri0"):
-    conf.set("sounduri0", "file:"+pathname2url(addDataPrefix("sounds/move1.%s" % EXT)))
+    conf.set("sounduri0",
+             "file:" + pathname2url(addDataPrefix("sounds/move1.%s" % EXT)))
 if not conf.hasKey("sounduri1"):
-    conf.set("sounduri1", "file:"+pathname2url(addDataPrefix("sounds/check1.%s" % EXT)))
+    conf.set("sounduri1",
+             "file:" + pathname2url(addDataPrefix("sounds/check1.%s" % EXT)))
 if not conf.hasKey("sounduri2"):
-    conf.set("sounduri2", "file:"+pathname2url(addDataPrefix("sounds/capture1.%s" % EXT)))
+    conf.set("sounduri2",
+             "file:" + pathname2url(addDataPrefix("sounds/capture1.%s" % EXT)))
 if not conf.hasKey("sounduri3"):
-    conf.set("sounduri3", "file:"+pathname2url(addDataPrefix("sounds/start1.%s" % EXT)))
+    conf.set("sounduri3",
+             "file:" + pathname2url(addDataPrefix("sounds/start1.%s" % EXT)))
 if not conf.hasKey("sounduri4"):
-    conf.set("sounduri4", "file:"+pathname2url(addDataPrefix("sounds/win1.%s" % EXT)))
+    conf.set("sounduri4",
+             "file:" + pathname2url(addDataPrefix("sounds/win1.%s" % EXT)))
 if not conf.hasKey("sounduri5"):
-    conf.set("sounduri5", "file:"+pathname2url(addDataPrefix("sounds/lose1.%s" % EXT)))
+    conf.set("sounduri5",
+             "file:" + pathname2url(addDataPrefix("sounds/lose1.%s" % EXT)))
 if not conf.hasKey("sounduri6"):
-    conf.set("sounduri6", "file:"+pathname2url(addDataPrefix("sounds/draw1.%s" % EXT)))
+    conf.set("sounduri6",
+             "file:" + pathname2url(addDataPrefix("sounds/draw1.%s" % EXT)))
 if not conf.hasKey("sounduri7"):
-    conf.set("sounduri7", "file:"+pathname2url(addDataPrefix("sounds/obs_mov.%s" % EXT)))
+    conf.set("sounduri7",
+             "file:" + pathname2url(addDataPrefix("sounds/obs_mov.%s" % EXT)))
 if not conf.hasKey("sounduri8"):
-    conf.set("sounduri8", "file:"+pathname2url(addDataPrefix("sounds/obs_end.%s" % EXT)))
+    conf.set("sounduri8",
+             "file:" + pathname2url(addDataPrefix("sounds/obs_end.%s" % EXT)))
 if not conf.hasKey("sounduri9"):
-    conf.set("sounduri9", "file:"+pathname2url(addDataPrefix("sounds/alarm.%s" % EXT)))
+    conf.set("sounduri9",
+             "file:" + pathname2url(addDataPrefix("sounds/alarm.%s" % EXT)))
 if not conf.hasKey("sounduri10"):
-    conf.set("sounduri10", "file:"+pathname2url(addDataPrefix("sounds/invalid.%s" % EXT)))
+    conf.set("sounduri10",
+             "file:" + pathname2url(addDataPrefix("sounds/invalid.%s" % EXT)))
+
 
 class SoundTab:
 
@@ -298,39 +330,41 @@ class SoundTab:
     }
 
     _player = None
+
     @classmethod
-    def getPlayer (cls):
+    def getPlayer(cls):
         if not cls._player:
             cls._player = gstreamer.sound_player
         return cls._player
 
     @classmethod
-    def playAction (cls, action):
+    def playAction(cls, action):
         if not conf.get("useSounds", True):
             return
 
         if isinstance(action, str):
-            no = cls.actionToKeyNo[action]
-        else: no = action
-        typ = conf.get("soundcombo%d" % no, SOUND_MUTE)
+            key_no = cls.actionToKeyNo[action]
+        else:
+            key_no = action
+        typ = conf.get("soundcombo%d" % key_no, SOUND_MUTE)
         if typ == SOUND_BEEP:
             sys.stdout.write("\a")
             sys.stdout.flush()
         elif typ == SOUND_URI:
-            uri = conf.get("sounduri%d" % no, "")
+            uri = conf.get("sounduri%d" % key_no, "")
             if not os.path.isfile(url2pathname(uri[5:])):
-                conf.set("soundcombo%d" % no, SOUND_MUTE)
+                conf.set("soundcombo%d" % key_no, SOUND_MUTE)
                 return
             cls.getPlayer().play(uri)
 
-    def __init__ (self, widgets):
+    def __init__(self, widgets):
 
         # Init open dialog
 
-        opendialog = Gtk.FileChooserDialog (
-                _("Open Sound File"), None, Gtk.FileChooserAction.OPEN,
-                 (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN,
-                  Gtk.ResponseType.ACCEPT))
+        opendialog = Gtk.FileChooserDialog(
+            _("Open Sound File"), None, Gtk.FileChooserAction.OPEN,
+            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN,
+             Gtk.ResponseType.ACCEPT))
 
         for dir in self.SOUND_DIRS:
             if os.path.isdir(dir):
@@ -358,57 +392,59 @@ class SoundTab:
 
         # Set-up combos
 
-        def callback (combobox, index):
+        def callback(combobox, index):
             if combobox.get_active() == SOUND_SELECT:
                 if opendialog.run() == Gtk.ResponseType.ACCEPT:
                     uri = opendialog.get_uri()
                     model = combobox.get_model()
-                    conf.set("sounduri%d"%index, uri)
+                    conf.set("sounduri%d" % index, uri)
                     label = unquote(os.path.split(uri)[1])
                     if len(model) == 3:
                         model.append([audioIco, label])
                     else:
-                        model.set(model.get_iter((3,)), 1, label)
+                        model.set(model.get_iter((3, )), 1, label)
                     combobox.set_active(3)
                 else:
-                    combobox.set_active(conf.get("soundcombo%d"%index,SOUND_MUTE))
+                    combobox.set_active(conf.get("soundcombo%d" % index,
+                                                 SOUND_MUTE))
                 opendialog.hide()
 
         for i in range(self.COUNT_OF_SOUNDS):
-            combo = widgets["soundcombo%d"%i]
-            uistuff.createCombo (combo, items)
-            combo.set_active(0)
+            combo = widgets["sound%dcombo" % i]
+            uistuff.createCombo(combo, items, name="soundcombo%d" % i)
+            # combo.set_active(0)
             combo.connect("changed", callback, i)
 
-            label = widgets["soundlabel%d"%i]
+            label = widgets["soundlabel%d" % i]
             label.props.mnemonic_widget = combo
 
-            uri = conf.get("sounduri%d"%i,"")
+            uri = conf.get("sounduri%d" % i, "")
             if os.path.isfile(url2pathname(uri[5:])):
                 model = combo.get_model()
                 model.append([audioIco, unquote(os.path.split(uri)[1])])
-                combo.set_active(3)
+                # combo.set_active(3)
 
         for i in range(self.COUNT_OF_SOUNDS):
-            if conf.get("soundcombo%d"%i, SOUND_MUTE) == SOUND_URI and \
-                    not os.path.isfile(url2pathname(conf.get("sounduri%d"%i,"")[5:])):
-                conf.set("soundcombo%d"%i, SOUND_MUTE)
-            uistuff.keep(widgets["soundcombo%d"%i], "soundcombo%d"%i)
+            if conf.get("soundcombo%d" % i, SOUND_MUTE) == SOUND_URI and \
+                    not os.path.isfile(url2pathname(conf.get("sounduri%d" % i, "")[5:])):
+                conf.set("soundcombo%d" % i, SOUND_MUTE)
+            uistuff.keep(widgets["sound%dcombo" % i], "soundcombo%d" % i)
 
         # Init play button
 
-        def playCallback (button, index):
+        def playCallback(button, index):
             SoundTab.playAction(index)
 
-        for i in range (self.COUNT_OF_SOUNDS):
-            button = widgets["soundbutton%d"%i]
+        for i in range(self.COUNT_OF_SOUNDS):
+            button = widgets["sound%dbutton" % i]
             button.connect("clicked", playCallback, i)
 
         # Init 'use sound" checkbutton
 
-        def checkCallBack (*args):
+        def checkCallBack(*args):
             checkbox = widgets["useSounds"]
-            widgets["frame23"].set_property("sensitive", checkbox.get_active())
+            widgets["sounds_frame"].set_property("sensitive", checkbox.get_active())
+
         conf.notify_add("useSounds", checkCallBack)
         widgets["useSounds"].set_active(True)
         uistuff.keep(widgets["useSounds"], "useSounds")
@@ -420,13 +456,11 @@ class SoundTab:
 
         uistuff.keep(widgets["alarm_spin"], "alarm_spin", first_value=15)
 
-################################################################################
-# Panel initing                                                               #
-################################################################################
+# Panel initing
+
 
 class PanelTab:
-
-    def __init__ (self, widgets):
+    def __init__(self, widgets):
         # Put panels in trees
         self.widgets = widgets
 
@@ -446,24 +480,28 @@ class PanelTab:
             text = "<b>%s</b>\n%s" % (panel.__title__, panel.__desc__)
             store.append((checked, panel_icon, text, panel))
 
-        self.tv = widgets["treeview1"]
+        self.tv = widgets["panels_treeview"]
         self.tv.set_model(store)
 
         self.widgets['panel_about_button'].connect('clicked', self.panel_about)
-        self.widgets['panel_enable_button'].connect('toggled', self.panel_toggled)
+        self.widgets['panel_enable_button'].connect('toggled',
+                                                    self.panel_toggled)
         self.tv.get_selection().connect('changed', self.selection_changed)
 
         pixbuf = Gtk.CellRendererPixbuf()
         pixbuf.props.yalign = 0
         pixbuf.props.ypad = 3
         pixbuf.props.xpad = 3
-        self.tv.append_column(Gtk.TreeViewColumn("Icon", pixbuf, pixbuf=1, sensitive=0))
+        self.tv.append_column(Gtk.TreeViewColumn("Icon",
+                                                 pixbuf,
+                                                 pixbuf=1,
+                                                 sensitive=0))
 
         uistuff.appendAutowrapColumn(self.tv, "Name", markup=2, sensitive=0)
 
-        widgets['notebook1'].connect("switch-page", self.__on_switch_page)
-        widgets["preferences"].connect("show", self.__on_show_window)
-        widgets["preferences"].connect("hide", self.__on_hide_window)
+        widgets['preferences_notebook'].connect("switch-page", self.__on_switch_page)
+        widgets["preferences_dialog"].connect("show", self.__on_show_window)
+        widgets["preferences_dialog"].connect("hide", self.__on_hide_window)
 
     def selection_changed(self, treeselection):
         store, iter = self.tv.get_selection().get_selected()
@@ -476,20 +514,22 @@ class PanelTab:
 
     def panel_about(self, button):
         store, iter = self.tv.get_selection().get_selected()
-        assert iter # The button should only be clickable when we have a selection
+        assert iter  # The button should only be clickable when we have a selection
         path = store.get_path(iter)
         panel = store[path][3]
 
-        d = Gtk.MessageDialog (type=Gtk.MessageType.INFO, buttons=Gtk.ButtonsType.CLOSE)
-        d.set_markup ("<big><b>%s</b></big>" % panel.__title__)
-        text = panel.__about__ if hasattr(panel, '__about__') else _('Undescribed panel')
-        d.format_secondary_text (text)
+        d = Gtk.MessageDialog(type=Gtk.MessageType.INFO,
+                              buttons=Gtk.ButtonsType.CLOSE)
+        d.set_markup("<big><b>%s</b></big>" % panel.__title__)
+        text = panel.__about__ if hasattr(
+            panel, '__about__') else _('Undescribed panel')
+        d.format_secondary_text(text)
         d.run()
         d.hide()
 
     def panel_toggled(self, button):
         store, iter = self.tv.get_selection().get_selected()
-        assert iter # The button should only be clickable when we have a selection
+        assert iter  # The button should only be clickable when we have a selection
         path = store.get_path(iter)
         active = button.get_active()
         if store[path][0] == active:
@@ -509,7 +549,8 @@ class PanelTab:
             leaf.dock(docks[name][1], EAST, docks[name][0], name)
         else:
             try:
-                notebooks[name].get_parent().get_parent().undock(notebooks[name])
+                notebooks[name].get_parent().get_parent().undock(notebooks[
+                    name])
             except AttributeError:
                 # A new panel appeared in the panels directory
                 leaf = notebooks["board"].get_parent().get_parent()
@@ -526,10 +567,11 @@ class PanelTab:
     def __on_switch_page(self, notebook, page, page_num):
         if notebook.get_nth_page(page_num) == self.widgets['sidepanels']:
             self.showit()
-        else: self.hideit()
+        else:
+            self.hideit()
 
     def __on_show_window(self, widget):
-        notebook = self.widgets['notebook1']
+        notebook = self.widgets['preferences_notebook']
         page_num = notebook.get_current_page()
         if notebook.get_nth_page(page_num) == self.widgets['sidepanels']:
             self.showit()
@@ -538,58 +580,64 @@ class PanelTab:
         self.hideit()
 
 
-
-#############################################################################
-# Theme initing                                                             #
-#############################################################################
+# Theme initing
 
 
 class ThemeTab:
+    """ :Description: Allows the setting of various user specific chess
+        sets and board colours
+    """
+    def __init__(self, widgets):
 
-    def __init__ (self, widgets):
-
-        #################
         # Board Colours
-        #################
 
-        def on_colour_set_light(color_btn):
-            conf.set('lightcolour',widgets['light_cbtn'].get_color().to_string())
+        style_ctxt = widgets["window1"].get_style_context()
+        LIGHT = hexcol(style_ctxt.lookup_color("p_light_color")[1])
+        DARK = hexcol(style_ctxt.lookup_color("p_dark_color")[1])
 
-        widgets["light_cbtn"].connect_after("color-set",
-                                                on_colour_set_light)
+        def onColourSetLight(_):
+            """ :Description: Sets the light squares of the chess board
+                to the value selected in the colour picker
+            """
+            conf.set('lightcolour',
+                     widgets['light_cbtn'].get_color().to_string())
 
-        def on_colour_set_dark(color_btn):
-            conf.set('darkcolour',widgets['dark_cbtn'].get_color().to_string())
+        widgets["light_cbtn"].connect_after("color-set", onColourSetLight)
 
-        widgets["dark_cbtn"].connect_after("color-set",
-                                                on_colour_set_dark)
+        def onColourSetDark(_):
+            """ :Description: Sets the dark squares of the chess board
+                to the value selected in the colour picker
+            """
+            conf.set('darkcolour',
+                     widgets['dark_cbtn'].get_color().to_string())
 
-        def on_reset_colour_clicked(btn):
-            conf.set("lightcolour", "#ffffffffffff")
-            conf.set("darkcolour", "#aaaaaaaaaaaa")
+        widgets["dark_cbtn"].connect_after("color-set", onColourSetDark)
 
-        widgets["reset_btn"].connect("clicked", on_reset_colour_clicked)
+        def onResetColourClicked(_):
+            """ :Description: Resets the chess board squares to factory default
+            """
+            conf.set("lightcolour", LIGHT)
+            conf.set("darkcolour", DARK)
 
+        widgets["reset_btn"].connect("clicked", onResetColourClicked)
 
         # Get the current board colours if set, if not set, set them to default
-        conf.set("lightcolour", conf.get("lightcolour", "#ffffffffffff"))
-        conf.set("darkcolour", conf.get("darkcolour", "#aaaaaaaaaaaa"))
+        conf.set("lightcolour", conf.get("lightcolour", LIGHT))
+        conf.set("darkcolour", conf.get("darkcolour", DARK))
 
         # Next 2 lines take a #hex str converts them to a color then to a RGBA representation
-        lightcolour =  Gdk.RGBA()
-        lightcolour.parse(conf.get("lightcolour", "#ffffffffffff"))
-        darkcolour =  Gdk.RGBA()
-        darkcolour.parse(conf.get("darkcolour", "#aaaaaaaaaaaa"))
+        self.lightcolour = Gdk.RGBA()
+        self.lightcolour.parse(conf.get("lightcolour", LIGHT))
+        self.darkcolour = Gdk.RGBA()
+        self.darkcolour.parse(conf.get("darkcolour", DARK))
 
         # Set the color swatches in preference to stored values
-        widgets['light_cbtn'].set_rgba(lightcolour)
-        widgets['dark_cbtn'].set_rgba(darkcolour)
+        widgets['light_cbtn'].set_rgba(self.lightcolour)
+        widgets['dark_cbtn'].set_rgba(self.darkcolour)
 
-
-        #############
         # Chess Sets
-        #############
-        self.themes = self.discover_themes()
+
+        self.themes = self.discoverThemes()
         store = Gtk.ListStore(GdkPixbuf.Pixbuf, str)
 
         for theme in self.themes:
@@ -599,27 +647,29 @@ class ThemeTab:
                 pixbuf = get_pixbuf(pngfile)
                 store.append((pixbuf, theme))
             else:
-                print("WARNING: No piece theme preview icons found. Please run create_theme_preview.sh !")
+                print(
+                    "WARNING: No piece theme preview icons found. Please run \
+                    create_theme_preview.sh !")
                 break
 
-        iconView = widgets["pieceTheme"]
-        iconView.set_model(store)
-        iconView.set_pixbuf_column(0)
-        iconView.set_text_column(1)
+        self.icon_view = widgets["pieceTheme"]
+        self.icon_view.set_model(store)
+        self.icon_view.set_pixbuf_column(0)
+        self.icon_view.set_text_column(1)
 
-        #############################################
-        # Hack to fix spacing problem in iconview
-        # http://stackoverflow.com/questions/14090094/what-causes-the-different-display-behaviour-for-a-gtkiconview-between-different
-        def keep_size(crt, *args):
+        def keepSize(crt, _):
+            """ :Description: Hack to fix spacing problem in iconview
+                http://stackoverflow.com/questions/14090094/what-causes-the-different-\
+                    display-behaviour-for-a-gtkiconview-between-different
+            """
             crt.handler_block(crt_notify)
             crt.set_property('width', 40)
             crt.handler_unblock(crt_notify)
 
-        crt, crp = iconView.get_cells()
-        crt_notify = crt.connect('notify', keep_size)
-        #############################################
+        crt = self.icon_view.get_cells()[0]
+        crt_notify = crt.connect('notify', keepSize)
 
-        def _get_active(iconview):
+        def _getActive(iconview):
             model = iconview.get_model()
             selected = iconview.get_selected_items()
 
@@ -628,67 +678,92 @@ class ThemeTab:
 
             indices = selected[0].get_indices()
             if indices:
-                i = indices[0]
-                theme = model[i][1]
+                idx = indices[0]
+                theme = model[idx][1]
                 Pieces.set_piece_theme(theme)
                 return theme
 
-        def _set_active(iconview, value):
+        def _setActive(iconview, value):
             try:
                 index = self.themes.index(value)
             except ValueError:
                 index = 0
-            iconview.select_path(Gtk.TreePath(index,))
+            iconview.select_path(Gtk.TreePath(index, ))
 
-        uistuff.keep(widgets["pieceTheme"], "pieceTheme", _get_active,
-                     _set_active, "Chessicons")
+        uistuff.keep(widgets["pieceTheme"], "pieceTheme", _getActive,
+                     _setActive, "Chessicons")
 
-    def discover_themes(self):
+    def discoverThemes(self):
+        """ :Description: Finds all the different chess sets that are present
+            in the pieces directory
+
+            :return: (a List) of themes
+        """
         themes = ['Pychess']
 
         pieces = addDataPrefix("pieces")
-        themes += [d.capitalize() for d in listdir(pieces) if isdir(os.path.join(pieces,d)) and d != 'ttf']
+        themes += [d.capitalize()
+                   for d in listdir(pieces)
+                   if isdir(os.path.join(pieces, d)) and d != 'ttf']
 
         ttf = addDataPrefix("pieces/ttf")
-        themes += ["ttf-" + splitext(d)[0].capitalize() for d in listdir(ttf) if splitext(d)[1] == '.ttf']
+        themes += ["ttf-" + splitext(d)[0].capitalize()
+                   for d in listdir(ttf) if splitext(d)[1] == '.ttf']
         themes.sort()
 
         return themes
 
-#############################################################################
-# Save initing                                                              #
-#############################################################################
+# Save initing
+
 
 class SaveTab:
-
-    def __init__ (self, widgets):
+    """ :Description: Allows the user to configure the structure of saved
+        game files name along with various game attributes such as elapse time
+        between moves and analysis engin evalutations
+    """
+    def __init__(self, widgets):
         # Init 'auto save" checkbutton
-        def checkCallBack (*args):
+        def checkCallBack(_):
+            """ :Description: Sets the various option based on user interaction with the
+                checkboxes in the gui
+            """
+
             checkbox = widgets["autoSave"]
-            widgets["autosave_grid"].set_property("sensitive", checkbox.get_active())
+            widgets["autosave_grid"].set_property("sensitive",
+                                                  checkbox.get_active())
+
         conf.notify_add("autoSave", checkCallBack)
         widgets["autoSave"].set_active(False)
         uistuff.keep(widgets["autoSave"], "autoSave")
-        checkCallBack()
+        checkCallBack(_)
 
         default_path = os.path.expanduser("~")
-        autoSavePath = conf.get("autoSavePath", default_path)
-        conf.set("autoSavePath", autoSavePath)
+        self.auto_save_path = conf.get("autoSavePath", default_path)
+        conf.set("autoSavePath", self.auto_save_path)
 
-        auto_save_chooser_dialog = Gtk.FileChooserDialog(_("Select auto save path"), None, Gtk.FileChooserAction.SELECT_FOLDER,
-            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
-        auto_save_chooser_button = Gtk.FileChooserButton.new_with_dialog(auto_save_chooser_dialog)
-        auto_save_chooser_button.set_current_folder(autoSavePath)
+        auto_save_chooser_dialog = Gtk.FileChooserDialog(
+            _("Select auto save path"), None,
+            Gtk.FileChooserAction.SELECT_FOLDER,
+            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN,
+             Gtk.ResponseType.OK))
+        auto_save_chooser_button = Gtk.FileChooserButton.new_with_dialog(
+            auto_save_chooser_dialog)
+        auto_save_chooser_button.set_current_folder(self.auto_save_path)
 
         widgets["savePathChooserDock"].add(auto_save_chooser_button)
         auto_save_chooser_button.show()
 
-        def select_auto_save(button):
+        def selectAutoSave(_):
+            """ :Description: Sets the auto save path for stored games if it
+                has changed since last time
+
+                :signal: Activated on receiving the 'current-folder-changed' signal
+            """
             new_directory = auto_save_chooser_dialog.get_filename()
-            if new_directory != autoSavePath:
+            if new_directory != self.auto_save_path:
                 conf.set("autoSavePath", new_directory)
 
-        auto_save_chooser_button.connect("current-folder-changed", select_auto_save)
+        auto_save_chooser_button.connect("current-folder-changed", selectAutoSave)
 
         conf.set("autoSaveFormat", conf.get("autoSaveFormat", "pychess"))
         uistuff.keep(widgets["autoSaveFormat"], "autoSaveFormat")
