@@ -10,7 +10,8 @@ from gi.repository import Gdk
 
 from pychess.compat import basestring, unicode
 from pychess.Utils import prettyPrintScore
-from pychess.Utils.const import *
+from pychess.Utils.const import WHITE, BLACK, FEN_EMPTY, reprResult
+
 from pychess.System import conf
 from pychess.System.idle_add import idle_add
 from pychess.System.Log import log
@@ -21,7 +22,6 @@ from pychess.Savers.pgn import move_count
 from pychess.Savers.pgnbase import nag2symbol
 from pychess.widgets.Background import set_textview_color
 from pychess.widgets.ChessClock import formatTime
-from pychess.Utils.TimeModel import TimeModel
 
 __title__ = _("Annotation")
 __active__ = True
@@ -48,16 +48,17 @@ level  = depth in variation tree (0 for mainline nodes, 1 for first level variat
 index  = in comment nodes the index of comment if more exist for a move
 """
 
+
 class Sidepanel(Gtk.TextView):
     def __init__(self):
         GObject.GObject.__init__(self)
 
-        #self.set_editable(False)
-        #self.set_cursor_visible(False)
+        # self.set_editable(False)
+        # self.set_cursor_visible(False)
         self.set_wrap_mode(Gtk.WrapMode.WORD)
 
         self.cursor_standard = Gdk.Cursor.new(Gdk.CursorType.LEFT_PTR)
-        #self.cursor_hand = Gdk.Cursor.new(Gdk.HAND2)
+        # self.cursor_hand = Gdk.Cursor.new(Gdk.HAND2)
         self.cursor_hand = Gdk.Cursor.new(Gdk.CursorType.HAND2)
 
         self.textview = self
@@ -94,12 +95,21 @@ class Sidepanel(Gtk.TextView):
         self.textbuffer.create_tag("scored3", foreground_rgba=color3)
         self.textbuffer.create_tag("scored4", foreground_rgba=color4)
         self.textbuffer.create_tag("scored5", foreground_rgba=color5)
-        self.textbuffer.create_tag("emt", foreground="darkgrey", weight=Pango.Weight.NORMAL)
+        self.textbuffer.create_tag("emt",
+                                   foreground="darkgrey",
+                                   weight=Pango.Weight.NORMAL)
         self.textbuffer.create_tag("comment", foreground="darkblue")
-        self.textbuffer.create_tag("variation-toplevel", weight=Pango.Weight.NORMAL)
-        self.textbuffer.create_tag("variation-even", foreground="darkgreen", style="italic")
-        self.textbuffer.create_tag("variation-uneven", foreground="darkred", style="italic")
-        self.textbuffer.create_tag("selected", background_full_height=True, background="grey")
+        self.textbuffer.create_tag("variation-toplevel",
+                                   weight=Pango.Weight.NORMAL)
+        self.textbuffer.create_tag("variation-even",
+                                   foreground="darkgreen",
+                                   style="italic")
+        self.textbuffer.create_tag("variation-uneven",
+                                   foreground="darkred",
+                                   style="italic")
+        self.textbuffer.create_tag("selected",
+                                   background_full_height=True,
+                                   background="grey")
         self.textbuffer.create_tag("margin", left_margin=4)
         self.textbuffer.create_tag("variation-margin0", left_margin=20)
         self.textbuffer.create_tag("variation-margin1", left_margin=36)
@@ -112,10 +122,10 @@ class Sidepanel(Gtk.TextView):
 
         self.gamewidget = gmwidg
         self.boardview = gmwidg.board.view
-        self.boardview.connect("shown_changed", self.shown_changed)
+        self.boardview.connect("shownChanged", self.shownChanged)
 
         self.gamemodel = gmwidg.board.view.model
-        self.gamemodel.connect_after("game_loaded", self.update)
+        self.gamemodel.connect_after("game_loaded", self.game_loaded)
         self.gamemodel.connect_after("game_changed", self.game_changed)
         self.gamemodel.connect_after("game_started", self.update)
         self.gamemodel.connect_after("game_ended", self.update)
@@ -128,30 +138,38 @@ class Sidepanel(Gtk.TextView):
 
         # Connect to preferences
         self.fan = conf.get("figuresInNotation", False)
+
         def figuresInNotationCallback(none):
             self.fan = conf.get("figuresInNotation", False)
             self.update()
+
         conf.notify_add("figuresInNotation", figuresInNotationCallback)
 
         # Elapsed move time
         self.showEmt = conf.get("showEmt", False)
+
         def showEmtCallback(none):
             self.showEmt = conf.get("showEmt", False)
             self.update()
+
         conf.notify_add("showEmt", showEmtCallback)
 
         # Blunders
         self.showBlunder = conf.get("showBlunder", False)
+
         def showBlunderCallback(none):
             self.showBlunder = conf.get("showBlunder", False)
             self.update()
+
         conf.notify_add("showBlunder", showBlunderCallback)
 
         # Eval values
         self.showEval = conf.get("showEval", False)
+
         def showEvalCallback(none):
             self.showEval = conf.get("showEval", False)
             self.update()
+
         conf.notify_add("showEval", showEvalCallback)
 
         return __widget__
@@ -178,22 +196,24 @@ class Sidepanel(Gtk.TextView):
         """ Handles mouse cursor changes (standard/hand) """
 
         if (event.is_hint):
-            #(x, y, state) = event.window.get_pointer()
+            # (x, y, state) = event.window.get_pointer()
             (ign, x, y, state) = event.window.get_pointer()
         else:
             x = event.x
             y = event.y
-            state = event.get_state()
+            # state = event.get_state()
 
-        if self.textview.get_window_type(event.window) != Gtk.TextWindowType.TEXT:
+        if self.textview.get_window_type(
+                event.window) != Gtk.TextWindowType.TEXT:
             event.window.set_cursor(self.cursor_standard)
             return True
 
-        (x, y) = self.textview.window_to_buffer_coords(Gtk.TextWindowType.WIDGET, int(x), int(y))
+        (x, y) = self.textview.window_to_buffer_coords(
+            Gtk.TextWindowType.WIDGET, int(x), int(y))
         it = self.textview.get_iter_at_location(x, y)
         offset = it.get_offset()
         for node in self.nodelist:
-            if offset >= node["start"] and offset < node["end"] and not "vari" in node:
+            if offset >= node["start"] and offset < node["end"] and "vari" not in node:
                 event.window.set_cursor(self.cursor_hand)
                 return True
         event.window.set_cursor(self.cursor_standard)
@@ -203,7 +223,8 @@ class Sidepanel(Gtk.TextView):
         """ Calls setShownBoard() or edit_comment() on mouse click, or pops-up local menu """
 
         (wx, wy) = event.get_coords()
-        (x, y) = self.textview.window_to_buffer_coords(Gtk.TextWindowType.WIDGET, int(wx), int(wy))
+        (x, y) = self.textview.window_to_buffer_coords(
+            Gtk.TextWindowType.WIDGET, int(wx), int(wy))
         it = self.textview.get_iter_at_location(x, y)
         offset = it.get_offset()
 
@@ -215,10 +236,10 @@ class Sidepanel(Gtk.TextView):
                 break
         if node is None:
             return True
-        #print("-------------------------------------------------------")
-        #print("index is:", self.nodelist.index(node))
-        #print(node)
-        #print("-------------------------------------------------------")
+        # print("-------------------------------------------------------")
+        # print("index is:", self.nodelist.index(node))
+        # print(node)
+        # print("-------------------------------------------------------")
         # left mouse click
         if event.button == 1:
             if "vari" in node:
@@ -245,9 +266,10 @@ class Sidepanel(Gtk.TextView):
                         break
 
                 if len(self.gamemodel.boards) > 1 and board == self.gamemodel.boards[1].board and \
-                    not self.gamemodel.boards[0].board.children:
+                        not self.gamemodel.boards[0].board.children:
                     menuitem = Gtk.MenuItem(_("Add start comment"))
-                    menuitem.connect('activate', self.edit_comment, self.gamemodel.boards[0].board, 0)
+                    menuitem.connect('activate', self.edit_comment,
+                                     self.gamemodel.boards[0].board, 0)
                     self.menu.append(menuitem)
 
                 if position == -1:
@@ -256,19 +278,17 @@ class Sidepanel(Gtk.TextView):
                     self.menu.append(menuitem)
                 else:
                     menuitem = Gtk.MenuItem(_("Edit comment"))
-                    menuitem.connect('activate', self.edit_comment, board, position)
+                    menuitem.connect('activate', self.edit_comment, board,
+                                     position)
                     self.menu.append(menuitem)
 
                 symbol_menu1 = Gtk.Menu()
-                for nag, menutext in (("$1", "!"),
-                                      ("$2", "?"),
-                                      ("$3", "!!"),
-                                      ("$4", "??"),
-                                      ("$5", "!?"),
-                                      ("$6", "?!"),
+                for nag, menutext in (("$1", "!"), ("$2", "?"), ("$3", "!!"),
+                                      ("$4", "??"), ("$5", "!?"), ("$6", "?!"),
                                       ("$7", _("Forced move"))):
                     menuitem = Gtk.MenuItem(menutext)
-                    menuitem.connect('activate', self.symbol_menu1_activate, board, nag)
+                    menuitem.connect('activate', self.symbol_menu1_activate,
+                                     board, nag)
                     symbol_menu1.append(menuitem)
 
                 menuitem = Gtk.MenuItem(_("Add move symbol"))
@@ -276,25 +296,16 @@ class Sidepanel(Gtk.TextView):
                 self.menu.append(menuitem)
 
                 symbol_menu2 = Gtk.Menu()
-                for nag, menutext in (("$10", "="),
-                                      ("$13", _("Unclear position")),
-                                      ("$14", "+="),
-                                      ("$15", "=+"),
-                                      ("$16", "±"),
-                                      ("$17", "∓"),
-                                      ("$18", "+-"),
-                                      ("$19", "-+"),
-                                      ("$20", "+--"),
-                                      ("$21", "--+"),
-                                      ("$22", _("Zugzwang")),
-                                      ("$32", _("Development adv.")),
-                                      ("$36", _("Initiative")),
-                                      ("$40", _("With attack")),
-                                      ("$44", _("Compensation")),
-                                      ("$132", _("Counterplay")),
-                                      ("$138", _("Time pressure"))):
+                for nag, menutext in (("$10", "="), ("$13", _("Unclear position")),
+                                      ("$14", "+="), ("$15", "=+"), ("$16", "±"), ("$17", "∓"),
+                                      ("$18", "+-"), ("$19", "-+"), ("$20", "+--"),
+                                      ("$21", "--+"), ("$22", _("Zugzwang")),
+                                      ("$32", _("Development adv.")), ("$36", _("Initiative")),
+                                      ("$40", _("With attack")), ("$44", _("Compensation")),
+                                      ("$132", _("Counterplay")), ("$138", _("Time pressure"))):
                     menuitem = Gtk.MenuItem(menutext)
-                    menuitem.connect('activate', self.symbol_menu2_activate, board, nag)
+                    menuitem.connect('activate', self.symbol_menu2_activate,
+                                     board, nag)
                     symbol_menu2.append(menuitem)
 
                 menuitem = Gtk.MenuItem(_("Add evaluation symbol"))
@@ -306,18 +317,18 @@ class Sidepanel(Gtk.TextView):
                 self.menu.append(menuitem)
 
                 self.menu.show_all()
-                self.menu.popup(None, None, None, None, event.button, event.time)
+                self.menu.popup(None, None, None, None, event.button,
+                                event.time)
         return True
 
     def copy_pgn(self, widget):
         self.gamewidget.copy_pgn()
 
     def edit_comment(self, widget=None, board=None, index=0):
-        dialog = Gtk.Dialog(_("Edit comment"),
-                     None,
-                     Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                     (Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,
-                      Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT))
+        dialog = Gtk.Dialog(
+            _("Edit comment"), None, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT, (
+                Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT, Gtk.STOCK_OK,
+                Gtk.ResponseType.ACCEPT))
 
         textedit = Gtk.TextView()
         textedit.set_editable(True)
@@ -370,7 +381,8 @@ class Sidepanel(Gtk.TextView):
     # Add evaluation symbol menu
     def symbol_menu2_activate(self, widget, board, nag):
         color = board.color
-        if color == WHITE and nag in ("$22", "$32", "$36", "$40", "$44", "$132", "$138"):
+        if color == WHITE and nag in ("$22", "$32", "$36", "$40", "$44",
+                                      "$132", "$138"):
             nag = "$%s" % (int(nag[1:]) + 1)
 
         if len(board.nags) == 0:
@@ -409,9 +421,9 @@ class Sidepanel(Gtk.TextView):
         return text
 
     def remove_variation(self, node):
-        shown_board = self.gamemodel.getBoardAtPly(self.boardview.shown, self.boardview.shownVariationIdx)
+        # shown_board = self.gamemodel.getBoardAtPly(self.boardview.shown, self.boardview.shown_variation_idx)
         # TODO
-        in_vari = True #shown_board in vari
+        in_vari = True  # shown_board in vari
 
         board = node["board"]
         parent = node["parent"]
@@ -451,7 +463,7 @@ class Sidepanel(Gtk.TextView):
 
         if not last_node:
             diff = end - start
-            for n in self.nodelist[self.nodelist.index(node)+1:]:
+            for n in self.nodelist[self.nodelist.index(node) + 1:]:
                 n["start"] -= diff
                 n["end"] -= diff
 
@@ -469,17 +481,20 @@ class Sidepanel(Gtk.TextView):
         if not iter.ends_tag(tag=self.new_line_tag):
             self.textbuffer.insert_with_tags_by_name(iter, "\n", "new_line")
         if level == 0:
-            self.textbuffer.insert_with_tags_by_name(iter, "[", "variation-toplevel", "variation-margin0")
-        elif (level+1) % 2 == 0:
-            self.textbuffer.insert_with_tags_by_name(iter, "(", "variation-even", "variation-margin1")
+            self.textbuffer.insert_with_tags_by_name(
+                iter, "[", "variation-toplevel", "variation-margin0")
+        elif (level + 1) % 2 == 0:
+            self.textbuffer.insert_with_tags_by_name(
+                iter, "(", "variation-even", "variation-margin1")
         else:
-            self.textbuffer.insert_with_tags_by_name(iter, "(", "variation-uneven", "variation-margin2")
+            self.textbuffer.insert_with_tags_by_name(
+                iter, "(", "variation-uneven", "variation-margin2")
 
         node = {}
         node["board"] = EMPTY_BOARD
         node["vari"] = None
         node["start"] = start
-        node["end"] =  iter.get_offset()
+        node["end"] = iter.get_offset()
 
         if index == -1:
             self.nodelist.append(node)
@@ -488,17 +503,22 @@ class Sidepanel(Gtk.TextView):
 
         return (iter.get_offset() - start, node)
 
-    def variation_end(self, iter, index, level, firstboard, parent, opening_node):
+    def variation_end(self, iter, index, level, firstboard, parent,
+                      opening_node):
         start = iter.get_offset()
         if level == 0:
-            self.textbuffer.insert_with_tags_by_name(iter, "]", "variation-toplevel", "variation-margin0")
-        elif (level+1) % 2 == 0:
-            self.textbuffer.insert_with_tags_by_name(iter, ")", "variation-even", "variation-margin1")
+            self.textbuffer.insert_with_tags_by_name(
+                iter, "]", "variation-toplevel", "variation-margin0")
+        elif (level + 1) % 2 == 0:
+            self.textbuffer.insert_with_tags_by_name(
+                iter, ")", "variation-even", "variation-margin1")
         else:
-            self.textbuffer.insert_with_tags_by_name(iter, ")", "variation-uneven", "variation-margin2")
+            self.textbuffer.insert_with_tags_by_name(
+                iter, ")", "variation-uneven", "variation-margin2")
 
-        self.textbuffer.insert_with_tags_by_name(iter, unicode("✖ "), "remove-variation")
-        chr = iter.get_char()
+        self.textbuffer.insert_with_tags_by_name(iter, unicode("✖ "),
+                                                 "remove-variation")
+        # chr = iter.get_char()
 
         # somehow iter.begins_tag() doesn't work, so we use get_char() instead
         if iter.get_char() != "\n":
@@ -509,7 +529,7 @@ class Sidepanel(Gtk.TextView):
         node["parent"] = parent
         node["vari"] = opening_node
         node["start"] = start
-        node["end"] =  iter.get_offset()
+        node["end"] = iter.get_offset()
 
         if index == -1:
             self.nodelist.append(node)
@@ -541,7 +561,7 @@ class Sidepanel(Gtk.TextView):
         diff = inserted_node["end"] - inserted_node["start"] - diff
 
         if len(self.nodelist) > index + 1:
-            for node in self.nodelist[index+1:]:
+            for node in self.nodelist[index + 1:]:
                 node["start"] += diff
                 node["end"] += diff
 
@@ -558,14 +578,20 @@ class Sidepanel(Gtk.TextView):
             self.textbuffer.apply_tag_by_name("margin", startIter, endIter)
             self.colorize_node(board.plyCount, startIter, endIter)
         elif level == 1:
-            self.textbuffer.apply_tag_by_name("variation-toplevel", startIter, endIter)
-            self.textbuffer.apply_tag_by_name("variation-margin0", startIter, endIter)
+            self.textbuffer.apply_tag_by_name("variation-toplevel", startIter,
+                                              endIter)
+            self.textbuffer.apply_tag_by_name("variation-margin0", startIter,
+                                              endIter)
         elif level % 2 == 0:
-            self.textbuffer.apply_tag_by_name("variation-even", startIter, endIter)
-            self.textbuffer.apply_tag_by_name("variation-margin1", startIter, endIter)
+            self.textbuffer.apply_tag_by_name("variation-even", startIter,
+                                              endIter)
+            self.textbuffer.apply_tag_by_name("variation-margin1", startIter,
+                                              endIter)
         else:
-            self.textbuffer.apply_tag_by_name("variation-uneven", startIter, endIter)
-            self.textbuffer.apply_tag_by_name("variation-margin2", startIter, endIter)
+            self.textbuffer.apply_tag_by_name("variation-uneven", startIter,
+                                              endIter)
+            self.textbuffer.apply_tag_by_name("variation-margin2", startIter,
+                                              endIter)
 
         node = {}
         node["board"] = board
@@ -591,11 +617,12 @@ class Sidepanel(Gtk.TextView):
 
         node_index = self.nodelist.index(node) + 1
 
-        inserted_node = self.insert_node(board, end, node_index, node["level"], node["parent"])
+        inserted_node = self.insert_node(board, end, node_index, node["level"],
+                                         node["parent"])
         diff = inserted_node["end"] - inserted_node["start"]
 
-        if len(self.nodelist) > node_index+1:
-            for node in self.nodelist[node_index+1:]:
+        if len(self.nodelist) > node_index + 1:
+            for node in self.nodelist[node_index + 1:]:
                 node["start"] += diff
                 node["end"] += diff
 
@@ -636,35 +663,46 @@ class Sidepanel(Gtk.TextView):
                 continue
             else:
                 # insert variation move
-                inserted_node = self.insert_node(board, end, next_node_index+i, level+1, parent)
+                inserted_node = self.insert_node(
+                    board, end, next_node_index + i, level + 1, parent)
                 diff += inserted_node["end"] - inserted_node["start"]
                 end = self.textbuffer.get_iter_at_offset(inserted_node["end"])
 
                 if ini_board is not None:
                     # insert initial variation comment
-                    inserted_comment = self.insert_comment(comment, board, parent, level=level+1, ini_board=ini_board)
-                    comment_diff = inserted_comment["end"] - inserted_comment["start"]
+                    inserted_comment = self.insert_comment(comment,
+                                                           board,
+                                                           parent,
+                                                           level=level + 1,
+                                                           ini_board=ini_board)
+                    comment_diff = inserted_comment["end"] - inserted_comment[
+                        "start"]
                     inserted_node["start"] += comment_diff
                     inserted_node["end"] += comment_diff
-                    end = self.textbuffer.get_iter_at_offset(inserted_node["end"])
+                    end = self.textbuffer.get_iter_at_offset(inserted_node[
+                        "end"])
                     diff += comment_diff
-                    leading = False
+                    # leading = False
                     next_node_index += 1
                     ini_board = None
 
         if score:
             # insert score of variation latest move as comment
             board.children.append(score)
-            inserted_node = self.insert_comment(score, board, parent, level=level+1)
+            inserted_node = self.insert_comment(score,
+                                                board,
+                                                parent,
+                                                level=level + 1)
             diff += inserted_node["end"] - inserted_node["start"]
             end = self.textbuffer.get_iter_at_offset(inserted_node["end"])
             next_node_index += 1
 
-        diff += self.variation_end(end, next_node_index + len(boards), level, boards[1], parent, opening_node)
+        diff += self.variation_end(end, next_node_index + len(boards), level,
+                                   boards[1], parent, opening_node)
 
         # adjust remaining stuff offsets
         if next_node_index > 0:
-            for node in self.nodelist[next_node_index + len(boards)+1:]:
+            for node in self.nodelist[next_node_index + len(boards) + 1:]:
                 node["start"] += diff
                 node["end"] += diff
 
@@ -683,22 +721,27 @@ class Sidepanel(Gtk.TextView):
         self.textbuffer.remove_tag_by_name("scored3", start, end)
         self.textbuffer.remove_tag_by_name("scored2", start, end)
         self.textbuffer.remove_tag_by_name("scored1", start, end)
-        if self.showBlunder and ply-1 in self.gamemodel.scores and ply in self.gamemodel.scores:
-            color = (ply-1) % 2
-            oldmoves, oldscore, olddepth = self.gamemodel.scores[ply-1]
+        if self.showBlunder and ply - 1 in self.gamemodel.scores and ply in self.gamemodel.scores:
+            color = (ply - 1) % 2
+            oldmoves, oldscore, olddepth = self.gamemodel.scores[ply - 1]
             oldscore = oldscore * -1 if color == BLACK else oldscore
             moves, score, depth = self.gamemodel.scores[ply]
             score = score * -1 if color == WHITE else score
-            diff = score-oldscore
-            if (diff > 400 and color==BLACK) or (diff < -400 and color==WHITE):
+            diff = score - oldscore
+            if (diff > 400 and color == BLACK) or (diff < -400 and
+                                                   color == WHITE):
                 self.textbuffer.apply_tag_by_name("scored5", start, end)
-            elif (diff > 200 and color==BLACK) or (diff < -200 and color==WHITE):
+            elif (diff > 200 and color == BLACK) or (diff < -200 and
+                                                     color == WHITE):
                 self.textbuffer.apply_tag_by_name("scored4", start, end)
-            elif (diff > 90 and color==BLACK) or (diff < -90 and color==WHITE):
+            elif (diff > 90 and color == BLACK) or (diff < -90 and
+                                                    color == WHITE):
                 self.textbuffer.apply_tag_by_name("scored3", start, end)
-            elif (diff > 50 and color==BLACK) or (diff < -50 and color==WHITE):
+            elif (diff > 50 and color == BLACK) or (diff < -50 and
+                                                    color == WHITE):
                 self.textbuffer.apply_tag_by_name("scored2", start, end)
-            elif (diff > 20 and color==BLACK) or (diff < -20 and color==WHITE):
+            elif (diff > 20 and color == BLACK) or (diff < -20 and
+                                                    color == WHITE):
                 self.textbuffer.apply_tag_by_name("scored1", start, end)
             else:
                 self.textbuffer.apply_tag_by_name("scored0", start, end)
@@ -731,7 +774,8 @@ class Sidepanel(Gtk.TextView):
 
         emt_eval = ""
         if self.showEmt and self.gamemodel.timemodel.hasTimes:
-            elapsed = gamemodel.timemodel.getElapsedMoveTime(board.plyCount - gamemodel.lowply)
+            elapsed = gamemodel.timemodel.getElapsedMoveTime(board.plyCount -
+                                                             gamemodel.lowply)
             emt_eval = "%s " % formatTime(elapsed)
 
         if self.showEval:
@@ -745,8 +789,9 @@ class Sidepanel(Gtk.TextView):
                 next_node = None
                 self.textbuffer.delete(end, self.textbuffer.get_end_iter())
             else:
-                next_node = self.nodelist[self.nodelist.index(node)+1]
-                next_start = self.textbuffer.get_iter_at_offset(next_node["start"])
+                next_node = self.nodelist[self.nodelist.index(node) + 1]
+                next_start = self.textbuffer.get_iter_at_offset(next_node[
+                    "start"])
                 self.textbuffer.delete(end, next_start)
             self.textbuffer.insert_with_tags_by_name(end, emt_eval, "emt")
 
@@ -759,8 +804,11 @@ class Sidepanel(Gtk.TextView):
     def update_selected_node(self):
         """ Update the selected node highlight """
 
-        self.textbuffer.remove_tag_by_name("selected", self.textbuffer.get_start_iter(), self.textbuffer.get_end_iter())
-        shown_board = self.gamemodel.getBoardAtPly(self.boardview.shown, self.boardview.shownVariationIdx)
+        self.textbuffer.remove_tag_by_name("selected",
+                                           self.textbuffer.get_start_iter(),
+                                           self.textbuffer.get_end_iter())
+        shown_board = self.gamemodel.getBoardAtPly(
+            self.boardview.shown, self.boardview.shown_variation_idx)
         start = None
         for node in self.nodelist:
             if node["board"] == shown_board.board:
@@ -770,16 +818,16 @@ class Sidepanel(Gtk.TextView):
                 break
 
         if start:
-            #self.textview.scroll_to_iter(start, within_margin=0.03)
+            # self.textview.scroll_to_iter(start, within_margin=0.03)
             self.textview.scroll_to_iter(start, 0.03, False, 0.00, 0.00)
 
     def insert_nodes(self, board, level=0, parent=None, result=None):
         """ Recursively builds the node tree """
 
-        end_iter = self.textbuffer.get_end_iter # Convenience shortcut to the function
+        end_iter = self.textbuffer.get_end_iter  # Convenience shortcut to the function
 
         while True:
-            start = end_iter().get_offset()
+            # start = end_iter().get_offset()
 
             if board is None:
                 break
@@ -788,7 +836,12 @@ class Sidepanel(Gtk.TextView):
             if board.prev is None:
                 for index, child in enumerate(board.children):
                     if isinstance(child, basestring):
-                        self.insert_comment(child, board, parent, index=index, level=level, ini_board=board)
+                        self.insert_comment(child,
+                                            board,
+                                            parent,
+                                            index=index,
+                                            level=level,
+                                            ini_board=board)
                 board = board.next
                 continue
 
@@ -796,24 +849,33 @@ class Sidepanel(Gtk.TextView):
                 self.insert_node(board, end_iter(), -1, level, parent)
 
             if self.showEmt and level == 0 and board.fen_was_applied and self.gamemodel.timemodel.hasTimes:
-                elapsed = self.gamemodel.timemodel.getElapsedMoveTime(board.plyCount - self.gamemodel.lowply)
-                self.textbuffer.insert_with_tags_by_name(end_iter(), "%s " % formatTime(elapsed), "emt")
+                elapsed = self.gamemodel.timemodel.getElapsedMoveTime(
+                    board.plyCount - self.gamemodel.lowply)
+                self.textbuffer.insert_with_tags_by_name(
+                    end_iter(), "%s " % formatTime(elapsed), "emt")
 
             if self.showEval and level == 0 and board.fen_was_applied and board.plyCount in self.gamemodel.scores:
                 moves, score, depth = self.gamemodel.scores[board.plyCount]
                 score = score * -1 if board.color == BLACK else score
-                endIter = self.textbuffer.get_iter_at_offset(end_iter().get_offset())
-                self.textbuffer.insert_with_tags_by_name(end_iter(), "%s " % prettyPrintScore(score, depth), "emt")
+                # endIter = self.textbuffer.get_iter_at_offset(end_iter().get_offset())
+                self.textbuffer.insert_with_tags_by_name(
+                    end_iter(), "%s " % prettyPrintScore(score, depth), "emt")
 
             for index, child in enumerate(board.children):
                 if isinstance(child, basestring):
                     # comment
-                    self.insert_comment(child, board, parent, index=index, level=level)
+                    self.insert_comment(child,
+                                        board,
+                                        parent,
+                                        index=index,
+                                        level=level)
                 else:
                     # variation
-                    diff, opening_node = self.variation_start(end_iter(), -1, level)
-                    self.insert_nodes(child[0], level+1, parent=board)
-                    self.variation_end(end_iter(), -1, level, child[1], board, opening_node)
+                    diff, opening_node = self.variation_start(end_iter(), -1,
+                                                              level)
+                    self.insert_nodes(child[0], level + 1, parent=board)
+                    self.variation_end(end_iter(), -1, level, child[1], board,
+                                       opening_node)
 
             if board.next:
                 board = board.next
@@ -821,9 +883,16 @@ class Sidepanel(Gtk.TextView):
                 break
 
         if result and result != "*":
-            self.textbuffer.insert_with_tags_by_name(end_iter(), " "+result, "move")
+            self.textbuffer.insert_with_tags_by_name(end_iter(), " " + result,
+                                                     "move")
 
-    def insert_comment(self, comment, board, parent, index=0, level=0, ini_board=None):
+    def insert_comment(self,
+                       comment,
+                       board,
+                       parent,
+                       index=0,
+                       level=0,
+                       ini_board=None):
         comment = re.sub("\[%.*?\]", "", comment)
         if not comment:
             return
@@ -840,7 +909,8 @@ class Sidepanel(Gtk.TextView):
                 break
         start = end_iter.get_offset()
 
-        self.textbuffer.insert_with_tags_by_name(end_iter, comment+" ", "comment")
+        self.textbuffer.insert_with_tags_by_name(end_iter, comment + " ",
+                                                 "comment")
 
         node = {}
         node["board"] = ini_board if ini_board is not None else board
@@ -850,7 +920,7 @@ class Sidepanel(Gtk.TextView):
         node["level"] = level
         node["start"] = start
         node["end"] = end_iter.get_offset()
-        self.nodelist.insert(pos if ini_board is not None else pos+1, node)
+        self.nodelist.insert(pos if ini_board is not None else pos + 1, node)
 
         return node
 
@@ -865,30 +935,33 @@ class Sidepanel(Gtk.TextView):
         self.textbuffer.insert_with_tags_by_name(end_iter(), text, "head2")
         white_elo = gm.tags.get('WhiteElo')
         if white_elo:
-            self.textbuffer.insert_with_tags_by_name(end_iter(), " %s" % white_elo, "head1")
+            self.textbuffer.insert_with_tags_by_name(end_iter(), " %s" %
+                                                     white_elo, "head1")
 
         self.textbuffer.insert_with_tags_by_name(end_iter(), " - ", "head1")
 
-        #text = gm.tags['Black']
+        # text = gm.tags['Black']
         text = repr(gm.players[1])
         self.textbuffer.insert_with_tags_by_name(end_iter(), text, "head2")
         black_elo = gm.tags.get('BlackElo')
         if black_elo:
-            self.textbuffer.insert_with_tags_by_name(end_iter(), " %s" % black_elo, "head1")
+            self.textbuffer.insert_with_tags_by_name(end_iter(), " %s" %
+                                                     black_elo, "head1")
 
         status = reprResult[gm.status]
         if status != '*':
             result = status
         else:
             result = gm.tags['Result']
-        self.textbuffer.insert_with_tags_by_name(end_iter(), ' ' + result + '\n', "head2")
+        self.textbuffer.insert_with_tags_by_name(end_iter(),
+                                                 ' ' + result + '\n', "head2")
 
         text = ""
         time_control = gm.tags.get('TimeControl')
         if time_control:
             mins, inc = time_control.split('+')
             mins = int(mins) / 60
-            mins =  "{:.0f}".format(mins)
+            mins = "{:.0f}".format(mins)
             if inc != '0':
                 text += mins + ' mins + ' + inc + ' secs '
             else:
@@ -912,34 +985,38 @@ class Sidepanel(Gtk.TextView):
 
         game_date = gm.tags.get('Date')
         if game_date is None:
-            game_date = "%02d.%02d.%02d" % (gm.tags['Year'], gm.tags['Month'], gm.tags['Day'])
-        if (not '?' in game_date) and game_date.count('.') == 2:
+            game_date = "%02d.%02d.%02d" % (gm.tags['Year'], gm.tags['Month'],
+                                            gm.tags['Day'])
+        if ('?' not in game_date) and game_date.count('.') == 2:
             y, m, d = map(int, game_date.split('.'))
             # strftime() is limited to > 1900 dates
             try:
                 text += ', ' + datetime.date(y, m, d).strftime('%x')
             except ValueError:
                 text += ', ' + game_date
-        elif not '?' in game_date[:4]:
+        elif '?' not in game_date[:4]:
             text += ', ' + game_date[:4]
         self.textbuffer.insert_with_tags_by_name(end_iter(), text, "head1")
 
-
         eco = gm.tags.get('ECO')
         if eco:
-            self.textbuffer.insert_with_tags_by_name(end_iter(), "\n" + eco, "head2")
+            self.textbuffer.insert_with_tags_by_name(end_iter(), "\n" + eco,
+                                                     "head2")
             opening = gm.tags.get('Opening')
             if opening:
-                self.textbuffer.insert_with_tags_by_name(end_iter(), " - ", "head1")
-                self.textbuffer.insert_with_tags_by_name(end_iter(), opening, "head2")
+                self.textbuffer.insert_with_tags_by_name(end_iter(), " - ",
+                                                         "head1")
+                self.textbuffer.insert_with_tags_by_name(end_iter(), opening,
+                                                         "head2")
             variation = gm.tags.get('Variation')
             if variation:
-                self.textbuffer.insert_with_tags_by_name(end_iter(), ", ", "head1")
-                self.textbuffer.insert_with_tags_by_name(end_iter(), variation, "head2")
+                self.textbuffer.insert_with_tags_by_name(end_iter(), ", ",
+                                                         "head1")
+                self.textbuffer.insert_with_tags_by_name(end_iter(), variation,
+                                                         "head2")
 
         self.textbuffer.insert(end_iter(), "\n\n")
 
-
     @idle_add
     def update(self, *args):
         """ Update the entire notation tree """
@@ -958,7 +1035,7 @@ class Sidepanel(Gtk.TextView):
         self.update_selected_node()
 
     @idle_add
-    def shown_changed(self, boardview, shown):
+    def shownChanged(self, boardview, shown):
         self.update_selected_node()
 
     @idle_add
@@ -1001,8 +1078,10 @@ class Sidepanel(Gtk.TextView):
         self.nodelist.append(node)
 
         if self.showEmt and self.gamemodel.timed:
-            elapsed = self.gamemodel.timemodel.getElapsedMoveTime(board.plyCount - self.gamemodel.lowply)
-            self.textbuffer.insert_with_tags_by_name(end_iter(), "%s " % formatTime(elapsed), "emt")
+            elapsed = self.gamemodel.timemodel.getElapsedMoveTime(
+                board.plyCount - self.gamemodel.lowply)
+            self.textbuffer.insert_with_tags_by_name(
+                end_iter(), "%s " % formatTime(elapsed), "emt")
 
         self.update_selected_node()
 
@@ -1011,12 +1090,18 @@ class Sidepanel(Gtk.TextView):
         self.update()
         log.debug("annotationPanel.players_changed: returning")
 
+    def game_loaded(self, model, uri):
+        for ply in range(min(40, model.ply, len(model.boards))):
+            model.setOpening(ply)
+        self.update()
+
     def __movestr(self, board):
         move = board.lastMove
         if self.fan:
             movestr = unicode(toFAN(board.prev, move))
         else:
-            movestr =  unicode(toSAN(board.prev, move, True))
+            movestr = unicode(toSAN(board.prev, move, True))
         nagsymbols = "".join([nag2symbol(nag) for nag in board.nags])
         # To prevent wrap castling we will use hyphen bullet (U+2043)
-        return "%s%s%s" % (move_count(board), movestr.replace('-', unicode('⁃')), nagsymbols)
+        return "%s%s%s" % (move_count(board), movestr.replace(
+            '-', unicode('⁃')), nagsymbols)
